diff vp6.c @ 5711:dae0f80edbb3 libavcodec

move all model related tables into their own struct
author aurel
date Mon, 24 Sep 2007 22:29:11 +0000
parents 8f52599c4c6c
children 314be1cfdcb0
line wrap: on
line diff
--- a/vp6.c	Mon Sep 24 21:18:45 2007 +0000
+++ b/vp6.c	Mon Sep 24 22:29:11 2007 +0000
@@ -145,25 +145,27 @@
 {
     int i, pos, idx = 1;
 
-    s->coeff_index_to_pos[0] = 0;
+    s->modelp->coeff_index_to_pos[0] = 0;
     for (i=0; i<16; i++)
         for (pos=1; pos<64; pos++)
-            if (s->coeff_reorder[pos] == i)
-                s->coeff_index_to_pos[idx++] = pos;
+            if (s->modelp->coeff_reorder[pos] == i)
+                s->modelp->coeff_index_to_pos[idx++] = pos;
 }
 
 static void vp6_default_models_init(vp56_context_t *s)
 {
-    s->vector_model_dct[0] = 0xA2;
-    s->vector_model_dct[1] = 0xA4;
-    s->vector_model_sig[0] = 0x80;
-    s->vector_model_sig[1] = 0x80;
+    vp56_model_t *model = s->modelp;
 
-    memcpy(s->mb_types_stats, vp56_def_mb_types_stats, sizeof(s->mb_types_stats));
-    memcpy(s->vector_model_fdv, vp6_def_fdv_vector_model, sizeof(s->vector_model_fdv));
-    memcpy(s->vector_model_pdv, vp6_def_pdv_vector_model, sizeof(s->vector_model_pdv));
-    memcpy(s->coeff_model_runv, vp6_def_runv_coeff_model, sizeof(s->coeff_model_runv));
-    memcpy(s->coeff_reorder, vp6_def_coeff_reorder, sizeof(s->coeff_reorder));
+    model->vector_dct[0] = 0xA2;
+    model->vector_dct[1] = 0xA4;
+    model->vector_sig[0] = 0x80;
+    model->vector_sig[1] = 0x80;
+
+    memcpy(model->mb_types_stats, vp56_def_mb_types_stats, sizeof(model->mb_types_stats));
+    memcpy(model->vector_fdv, vp6_def_fdv_vector_model, sizeof(model->vector_fdv));
+    memcpy(model->vector_pdv, vp6_def_pdv_vector_model, sizeof(model->vector_pdv));
+    memcpy(model->coeff_runv, vp6_def_runv_coeff_model, sizeof(model->coeff_runv));
+    memcpy(model->coeff_reorder, vp6_def_coeff_reorder, sizeof(model->coeff_reorder));
 
     vp6_coeff_order_table_init(s);
 }
@@ -171,29 +173,31 @@
 static void vp6_parse_vector_models(vp56_context_t *s)
 {
     vp56_range_coder_t *c = &s->c;
+    vp56_model_t *model = s->modelp;
     int comp, node;
 
     for (comp=0; comp<2; comp++) {
         if (vp56_rac_get_prob(c, vp6_sig_dct_pct[comp][0]))
-            s->vector_model_dct[comp] = vp56_rac_gets_nn(c, 7);
+            model->vector_dct[comp] = vp56_rac_gets_nn(c, 7);
         if (vp56_rac_get_prob(c, vp6_sig_dct_pct[comp][1]))
-            s->vector_model_sig[comp] = vp56_rac_gets_nn(c, 7);
+            model->vector_sig[comp] = vp56_rac_gets_nn(c, 7);
     }
 
     for (comp=0; comp<2; comp++)
         for (node=0; node<7; node++)
             if (vp56_rac_get_prob(c, vp6_pdv_pct[comp][node]))
-                s->vector_model_pdv[comp][node] = vp56_rac_gets_nn(c, 7);
+                model->vector_pdv[comp][node] = vp56_rac_gets_nn(c, 7);
 
     for (comp=0; comp<2; comp++)
         for (node=0; node<8; node++)
             if (vp56_rac_get_prob(c, vp6_fdv_pct[comp][node]))
-                s->vector_model_fdv[comp][node] = vp56_rac_gets_nn(c, 7);
+                model->vector_fdv[comp][node] = vp56_rac_gets_nn(c, 7);
 }
 
 static void vp6_parse_coeff_models(vp56_context_t *s)
 {
     vp56_range_coder_t *c = &s->c;
+    vp56_model_t *model = s->modelp;
     int def_prob[11];
     int node, cg, ctx, pos;
     int ct;    /* code type */
@@ -205,22 +209,22 @@
         for (node=0; node<11; node++)
             if (vp56_rac_get_prob(c, vp6_dccv_pct[pt][node])) {
                 def_prob[node] = vp56_rac_gets_nn(c, 7);
-                s->coeff_model_dccv[pt][node] = def_prob[node];
+                model->coeff_dccv[pt][node] = def_prob[node];
             } else if (s->framep[VP56_FRAME_CURRENT]->key_frame) {
-                s->coeff_model_dccv[pt][node] = def_prob[node];
+                model->coeff_dccv[pt][node] = def_prob[node];
             }
 
     if (vp56_rac_get(c)) {
         for (pos=1; pos<64; pos++)
             if (vp56_rac_get_prob(c, vp6_coeff_reorder_pct[pos]))
-                s->coeff_reorder[pos] = vp56_rac_gets(c, 4);
+                model->coeff_reorder[pos] = vp56_rac_gets(c, 4);
         vp6_coeff_order_table_init(s);
     }
 
     for (cg=0; cg<2; cg++)
         for (node=0; node<14; node++)
             if (vp56_rac_get_prob(c, vp6_runv_pct[cg][node]))
-                s->coeff_model_runv[cg][node] = vp56_rac_gets_nn(c, 7);
+                model->coeff_runv[cg][node] = vp56_rac_gets_nn(c, 7);
 
     for (ct=0; ct<3; ct++)
         for (pt=0; pt<2; pt++)
@@ -228,21 +232,22 @@
                 for (node=0; node<11; node++)
                     if (vp56_rac_get_prob(c, vp6_ract_pct[ct][pt][cg][node])) {
                         def_prob[node] = vp56_rac_gets_nn(c, 7);
-                        s->coeff_model_ract[pt][ct][cg][node] = def_prob[node];
+                        model->coeff_ract[pt][ct][cg][node] = def_prob[node];
                     } else if (s->framep[VP56_FRAME_CURRENT]->key_frame) {
-                        s->coeff_model_ract[pt][ct][cg][node] = def_prob[node];
+                        model->coeff_ract[pt][ct][cg][node] = def_prob[node];
                     }
 
     /* coeff_model_dcct is a linear combination of coeff_model_dccv */
     for (pt=0; pt<2; pt++)
         for (ctx=0; ctx<3; ctx++)
             for (node=0; node<5; node++)
-                s->coeff_model_dcct[pt][ctx][node] = av_clip(((s->coeff_model_dccv[pt][node] * vp6_dccv_lc[ctx][node][0] + 128) >> 8) + vp6_dccv_lc[ctx][node][1], 1, 255);
+                model->coeff_dcct[pt][ctx][node] = av_clip(((model->coeff_dccv[pt][node] * vp6_dccv_lc[ctx][node][0] + 128) >> 8) + vp6_dccv_lc[ctx][node][1], 1, 255);
 }
 
 static void vp6_parse_vector_adjustment(vp56_context_t *s, vp56_mv_t *vect)
 {
     vp56_range_coder_t *c = &s->c;
+    vp56_model_t *model = s->modelp;
     int comp;
 
     *vect = (vp56_mv_t) {0,0};
@@ -252,22 +257,22 @@
     for (comp=0; comp<2; comp++) {
         int i, delta = 0;
 
-        if (vp56_rac_get_prob(c, s->vector_model_dct[comp])) {
+        if (vp56_rac_get_prob(c, model->vector_dct[comp])) {
             static const uint8_t prob_order[] = {0, 1, 2, 7, 6, 5, 4};
             for (i=0; i<sizeof(prob_order); i++) {
                 int j = prob_order[i];
-                delta |= vp56_rac_get_prob(c, s->vector_model_fdv[comp][j])<<j;
+                delta |= vp56_rac_get_prob(c, model->vector_fdv[comp][j])<<j;
             }
             if (delta & 0xF0)
-                delta |= vp56_rac_get_prob(c, s->vector_model_fdv[comp][3])<<3;
+                delta |= vp56_rac_get_prob(c, model->vector_fdv[comp][3])<<3;
             else
                 delta |= 8;
         } else {
             delta = vp56_rac_get_tree(c, vp56_pva_tree,
-                                      s->vector_model_pdv[comp]);
+                                      model->vector_pdv[comp]);
         }
 
-        if (delta && vp56_rac_get_prob(c, s->vector_model_sig[comp]))
+        if (delta && vp56_rac_get_prob(c, model->vector_sig[comp]))
             delta = -delta;
 
         if (!comp)
@@ -280,8 +285,9 @@
 static void vp6_parse_coeff(vp56_context_t *s)
 {
     vp56_range_coder_t *c = s->ccp;
+    vp56_model_t *model = s->modelp;
     uint8_t *permute = s->scantable.permutated;
-    uint8_t *model, *model2, *model3;
+    uint8_t *model1, *model2, *model3;
     int coeff, sign, coeff_idx;
     int b, i, cg, idx, ctx;
     int pt = 0;    /* plane type (0 for Y, 1 for U or V) */
@@ -294,21 +300,21 @@
 
         ctx = s->left_block[vp56_b6to4[b]].not_null_dc
               + s->above_blocks[s->above_block_idx[b]].not_null_dc;
-        model = s->coeff_model_dccv[pt];
-        model2 = s->coeff_model_dcct[pt][ctx];
+        model1 = model->coeff_dccv[pt];
+        model2 = model->coeff_dcct[pt][ctx];
 
         for (coeff_idx=0; coeff_idx<64; ) {
             if ((coeff_idx>1 && ct==0) || vp56_rac_get_prob(c, model2[0])) {
                 /* parse a coeff */
                 if (vp56_rac_get_prob(c, model2[2])) {
                     if (vp56_rac_get_prob(c, model2[3])) {
-                        idx = vp56_rac_get_tree(c, vp56_pc_tree, model);
+                        idx = vp56_rac_get_tree(c, vp56_pc_tree, model1);
                         coeff = vp56_coeff_bias[idx];
                         for (i=vp56_coeff_bit_length[idx]; i>=0; i--)
                             coeff += vp56_rac_get_prob(c, vp56_coeff_parse_table[idx][i]) << i;
                     } else {
                         if (vp56_rac_get_prob(c, model2[4]))
-                            coeff = 3 + vp56_rac_get_prob(c, model[5]);
+                            coeff = 3 + vp56_rac_get_prob(c, model1[5]);
                         else
                             coeff = 2;
                     }
@@ -321,7 +327,7 @@
                 coeff = (coeff ^ -sign) + sign;
                 if (coeff_idx)
                     coeff *= s->dequant_ac;
-                idx = s->coeff_index_to_pos[coeff_idx];
+                idx = model->coeff_index_to_pos[coeff_idx];
                 s->block_coeff[b][permute[idx]] = coeff;
                 run = 1;
             } else {
@@ -331,7 +337,7 @@
                     if (!vp56_rac_get_prob(c, model2[1]))
                         break;
 
-                    model3 = s->coeff_model_runv[coeff_idx >= 6];
+                    model3 = model->coeff_runv[coeff_idx >= 6];
                     run = vp56_rac_get_tree(c, vp6_pcr_tree, model3);
                     if (!run)
                         for (run=9, i=0; i<6; i++)
@@ -340,7 +346,7 @@
             }
 
             cg = vp6_coeff_groups[coeff_idx+=run];
-            model = model2 = s->coeff_model_ract[pt][ct][cg];
+            model1 = model2 = model->coeff_ract[pt][ct][cg];
         }
 
         s->left_block[vp56_b6to4[b]].not_null_dc =
@@ -228,21 +232,22 @@
                     }
 
-    /* coeff_model_dcct is a linear combination of coeff_model_dccv */
+    /* coeff_dcct is a linear combination of coeff_dccv */
     for (pt=0; pt<2; pt++)
         for (ctx=0; ctx<3; ctx++)